==> UnderB-1.01.tar.gz: UnderB-1.01/c_lists.c <==

/*
Eagles Bulletin Board System
Copyright (C) 1994, Ray Rocker, rrrocker@rock.b11.ingr.com
                                rock@seabass.st.usm.edu
                                72673.2105@compuserve.com

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "client.h"

extern NAMELIST acctlist;
extern NAMELIST boardlist;

struct disp_list {
  int x;
  int y;
};

/*ARGSUSED*/
display_list_element(indx, name, arg)
int indx;
char *name;
void *arg;
{
  struct disp_list *info = arg;
  move(info->y, info->x);
  prints(name);
  (info->y)++;
  if (info->y == t_lines - 1) {
    info->y = 4;
    info->x+=(NAMELEN + 2);
  }
}
  
display_list(header, list)
char *header;
NAMELIST list;
{
  struct disp_list info;
  info.x = 0;
  info.y = 4;

  move(2,0);
  clrtobot();
  move(3,0);
  prints("%s\n", header);
  apply_namelist(list, display_list_element, &info);
}

SetOverrides()
{
  int done = 0, change = 0;
  char ans[7];
  NAME userid;
  NAMELIST overlist = NULL;
  extern int lang;

  clear();
  if (acctlist == NULL)
    bbs_acctnames(&acctlist);
  else
  {
   if (lang)
     prints("α   üũ ȵ˴ϴ.. ϼ.\n");
   else
     prints("Any change on userlist after you've logged in cannot be checked.\n");
  }

  if (bbs_get_overrides(&overlist) != S_OK) {
    prints("Can't get override list!\n");
    pressreturn();
    return FULLUPDATE;
  }
  if (lang)
    prints("Talk ̵ Ʈ \n");
  else
    prints("Edit Talk Override List\n");
  while (!done) {
    if (lang)
    {
      display_list("*** ̵ Ʈ  ***", overlist);
      getdata(1,0,"[A] ϱ, [R] , [Q] ? [Q]: ",
	    ans, sizeof(ans), DOECHO, 0);
    }
    else
    {
      display_list("*** Users on Override List ***", overlist);
      getdata(1,0,"[A]-Add, [R]-Remove, or [Q]-Quit? [Q]: ",
	    ans, sizeof(ans), DOECHO, 0);
    }
    switch (ans[0]) {
    case 'A': case 'a':
      move(2,0);
      if (lang)
        namecomplete(acctlist, " ұ: ", userid);
      else
        namecomplete(acctlist, "Add which user: ", userid);
      if (is_in_namelist(acctlist, userid) && 
          !is_in_namelist(overlist, userid)) {
        add_namelist(&overlist, userid, NULL);
	sort_list(&overlist);
        change++;
      }
      break;
    case 'R': case 'r':
      if (overlist == NULL) {
	if (lang)
          prints("ƹ !\n");
	else
          prints("No one to remove!\n");
        clrtobot();
	pressreturn();
      }
      else {
	if (lang)
	  namecomplete(overlist, " : ", userid);
	else
	  namecomplete(overlist, "Remove which user: ", userid);
	if (remove_namelist(&overlist, userid) == S_OK)
	  {
	    change++;
	    sort_list(&overlist);
	  }
      }
      break;
    default:
      done = 1;
    }
    move(2,0);
    clrtoeol();    
  }
  if (change) {
    if (bbs_set_overrides(overlist) == S_OK) {
      if (lang)
        prints("̵ Ʈ ٲϴ.\n");
      else
        prints("Override list was updated.\n");
    } else prints("Error setting override list!\n");
  } else {
    if (lang)
      prints("̵ Ʈ ٲ .\n");
    else
      prints("No changes to override list.\n");
  }
  free_namelist(&overlist);
  pressreturn();
  return FULLUPDATE;
}

SetBoardMgrs()
{
  int done = 0, change = 0;
  char ans[7];
  NAME namebuf;
  BOARD board;
  NAMELIST mgrlist = NULL;
  extern int lang;

  clear();
  bbs_boardnames(&boardlist);
  if (acctlist == NULL)
    bbs_acctnames(&acctlist);
  else
  {
   if (lang)
     prints("α   üũ ȵ˴ϴ.. ϼ.\n");
   else
     prints("Any change on userlist after you've logged in cannot be checked.\n");
  }


  if (lang)
    namecomplete(boardlist, "  Ŵ ұ: ", namebuf);
  else
    namecomplete(boardlist, "Set manager for which board: ", namebuf);

  if (namebuf[0] == '\0') return FULLUPDATE;
  else if (!is_in_namelist(boardlist, namebuf)) {
    if (lang)
      prints("Ӹ ׷  .\n");
    else
      prints("Invalid board name.\n");
    pressreturn();
    return FULLUPDATE;
  }
  if (bbs_get_board(namebuf, &board) != S_OK) {
    if (lang)
      prints("Ӹ ׷  .\n");
    else
      prints("Invalid board name.\n");
    pressreturn();
    return FULLUPDATE;
  }
  if (bbs_get_boardmgrs(board.name, &mgrlist) != S_OK) {
    if (lang)
      prints("Ŵ Ʈ Ȼ׿!\n");
    else
      prints("Can't get board manager list!\n");
    pressreturn();
    return FULLUPDATE;
  }

  prints("Edit Board Manager List\n");
  while (!done) {
    display_list("*** Board Managers ***", mgrlist);
    getdata(1,0,"[A]-Add, [R]-Remove, or [Q]-Quit? [Q]: ",
	    ans, sizeof(ans), DOECHO, 0);
    switch (ans[0]) {
    case 'A': case 'a':
      move(2,0);
      namecomplete(acctlist, "Add which user: ", namebuf);
      if (is_in_namelist(acctlist, namebuf) && 
          !is_in_namelist(mgrlist, namebuf)) {
        add_namelist(&mgrlist, namebuf, NULL);
	sort_list(&mgrlist);
        change++;
      }
      break;
    case 'R': case 'r':
      if (mgrlist == NULL) {
        prints("No one to remove!\n");
        clrtobot();
	pressreturn();
      }
      else {
	namecomplete(mgrlist, "Remove which user: ", namebuf);
	if (remove_namelist(&mgrlist, namebuf) == S_OK)
	  {
	    change++;
	    sort_list(&mgrlist);
	  }
      }
      break;
    default:
      done = 1;
    }
    move(2,0);
    clrtoeol();    
  }
  if (change) {
    if (bbs_set_boardmgrs(board.name, mgrlist) == S_OK)
      prints("Manager list for '%s' was updated.\n", board.name);
    else prints("Error setting manager list!\n");
  }
  else prints("No changes to manager list.\n");
  free_namelist(&mgrlist);
  pressreturn();
  return FULLUPDATE;
}

==> UnderB-1.04.tar.gz: UnderB-1.04/c_lists.c <==

/*
Eagles Bulletin Board System
Copyright (C) 1994, Ray Rocker, rrrocker@rock.b11.ingr.com
                                rock@seabass.st.usm.edu
                                72673.2105@compuserve.com

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "client.h"

extern NAMELIST acctlist;

struct disp_list {
  int x;
  int y;
};

/*ARGSUSED*/
display_list_element(indx, name, arg)
int indx;
char *name;
void *arg;
{
  struct disp_list *info = arg;
  move(info->y, info->x);
  prints(name);
  (info->y)++;
  if (info->y == t_lines - 1) {
    info->y = 4;
    info->x+=(NAMELEN + 2);
  }
}
  
display_list(header, list)
char *header;
NAMELIST list;
{
  struct disp_list info;
  info.x = 0;
  info.y = 4;

  move(2,0);
  clrtobot();
  move(3,0);
  prints("%s\n", header);
  apply_namelist(list, display_list_element, &info);
}

SetOverrides()
{
  int done = 0, change = 0;
  char ans[7];
  NAME userid;
  NAMELIST overlist = NULL;
  extern int lang;

  clear();
  if (acctlist == NULL)
    bbs_acctnames(&acctlist);
  create_namelist(&overlist, MAXOVERRIDE);
  bbs_get_overrides(&overlist);
  c_msg(INFO_OVERLIST, TRUE);
  while (!done) {
    if (lang)
    {
      display_list("*** ̵ Ʈ  ***", overlist);
      getdata(1,0,"[A] ϱ, [D] , [Q] ? [Q]: ",
	    ans, sizeof(ans), DOECHO, 0);
    }
    else
    {
      display_list("*** Users on Override List ***", overlist);
      getdata(1,0,"[A]-Add, [D]-Remove, or [Q]-Quit? [Q]: ",
	    ans, sizeof(ans), DOECHO, 0);
    }
    switch (ans[0]) {
    case 'A': case 'a':
      move(2,0);
      if (lang)
        namecomplete(acctlist, " ұ: ", userid);
      else
        namecomplete(acctlist, "Add which user: ", userid);
      if (is_in_namelist(acctlist, userid) && 
          !is_in_namelist(overlist, userid)) {
        add_namelist(&overlist, userid, NULL);
	sort_list(&overlist);
        change++;
      }
      break;
    case 'D': case 'd':
      if (overlist->size == 0) {
	c_msg(ERR_NOTHING, TRUE);
        clrtobot();
	pressreturn();
      } else {
	if (lang)
	  namecomplete(overlist, " : ", userid);
	else
	  namecomplete(overlist, "Remove which user: ", userid);
	if (remove_namelist(&overlist, userid) == S_OK)
	  {
	    change++;
	    sort_list(&overlist);
	  }
      }
      break;
    default:
      done = 1;
    }
    move(2,0);
    clrtoeol();    
  }
  if (change) {
    if (bbs_set_overrides(overlist) == S_OK)
      c_msg(INFO_CHANGED, TRUE);
    else
      c_msg(ERR_FAILURE, TRUE);
  } else {
    c_msg(INFO_CANCELLED, TRUE);
  }
  free_namelist(&overlist);
  pressreturn();
  return FULLUPDATE;
}

SetBoardMgrs()
{
  int done = 0, change = 0;
  char ans[7];
  NAME namebuf;
  BOARD board;
  NAMELIST mgrlist = NULL;
  NAMELIST boardlist = NULL;
  extern int lang;

  clear();
  bbs_boardnames(&boardlist);
  if (boardlist->size == 0) {
    c_msg(ERR_NOTHING, TRUE);
    free_namelist(&boardlist);
    pressreturn();
    return FULLUPDATE;
  }
  if (acctlist == NULL)
    bbs_acctnames(&acctlist);

  if (lang)
    namecomplete(boardlist, "  Ŵ ұ: ", namebuf);
  else
    namecomplete(boardlist, "Set manager for which board: ", namebuf);

  if (namebuf[0] == '\0')
    return FULLUPDATE;

  if (!is_in_namelist(boardlist, namebuf)) {
    c_msg(ERR_NOT_EXIST, TRUE);
    free_namelist(&boardlist);
    pressreturn();
    return FULLUPDATE;
  }
  if (bbs_get_board(namebuf, &board) != S_OK) {
    c_msg(ERR_FAILURE, TRUE);
    free_namelist(&boardlist);
    pressreturn();
    return FULLUPDATE;
  }
  create_namelist(&mgrlist, MAXMANAGER);
  bbs_get_boardmgrs(board.name, &mgrlist);
  c_msg(INFO_BMGR, TRUE);
  while (!done) {
    if (lang) {
      display_list("***   ***", mgrlist);
      getdata(1,0,"[A]-ϱ, [D]-, or [Q]-? [Q]: ",
	    ans, sizeof(ans), DOECHO, 0);
    } else {
      display_list("*** Board Managers ***", mgrlist);
      getdata(1,0,"[A]-Add, [D]-Delete, or [Q]-Quit? [Q]: ",
	    ans, sizeof(ans), DOECHO, 0);
    }
    switch (ans[0]) {
    case 'A': case 'a':
      move(2,0);
      if (lang)
        namecomplete(acctlist, " ұ: ", namebuf);
      else
        namecomplete(acctlist, "Add which user: ", namebuf);
      if (is_in_namelist(acctlist, namebuf) && 
          !is_in_namelist(mgrlist, namebuf)) {
        add_namelist(&mgrlist, namebuf, NULL);
	sort_list(&mgrlist);
        change++;
      }
      break;
    case 'D': case 'd':
      if (mgrlist->size == 0) {
	c_msg(ERR_NOTHING, TRUE);
        clrtobot();
	pressreturn();
      } else {
	if (lang)
	  namecomplete(mgrlist, " : ", namebuf);
	else
	  namecomplete(mgrlist, "Remove which user: ", namebuf);
	if (remove_namelist(&mgrlist, namebuf) == S_OK)
	  {
	    change++;
	    sort_list(&mgrlist);
	  }
      }
      break;
    default:
      done = 1;
    }
    move(2,0);
    clrtoeol();    
  }
  if (change) {
    if (bbs_set_boardmgrs(board.name, mgrlist) == S_OK)
      c_msg(INFO_CHANGED, TRUE);
    else
      c_msg(ERR_FAILURE, TRUE);
  } else
    c_msg(INFO_CANCELLED, TRUE);
  free_namelist(&mgrlist);
  free_namelist(&boardlist);
  pressreturn();
  return FULLUPDATE;
}
